==> sui-share-social-media-buttons-group-1.1.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import AtomButton from '@s-ui/react-atom-button';
import DEFAULT_SOCIAL_MEDIA_DICTIONARY, { DEFAULT_SOCIAL_MEDIA_BUTTONS } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
var BASE_CLASS = 'sui-ShareSocialMediaButtonsGroup';
export default function ShareSocialMediaButtonsGroup(_ref) {
  var _ref$buttonsToShow = _ref.buttonsToShow,
      buttonsToShow = _ref$buttonsToShow === void 0 ? DEFAULT_SOCIAL_MEDIA_BUTTONS : _ref$buttonsToShow,
      onShare = _ref.onShare,
      paramsUrlString = _ref.paramsUrlString,
      _ref$socialMediaDicti = _ref.socialMediaDictionary,
      socialMediaDictionaryFromProps = _ref$socialMediaDicti === void 0 ? DEFAULT_SOCIAL_MEDIA_DICTIONARY : _ref$socialMediaDicti;
  var socialMediaDictionary = buttonsToShow.map(function (key) {
    return Object.keys(socialMediaDictionaryFromProps).includes(key) && socialMediaDictionaryFromProps[key];
  });
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: socialMediaDictionary.map(function (_ref2, index) {
      var literal = _ref2.literal,
          url = _ref2.url,
          rest = _objectWithoutPropertiesLoose(_ref2, ["literal", "url"]);

      return /*#__PURE__*/_jsx(AtomButton, _extends({
        className: BASE_CLASS + "-button",
        href: "" + url + paramsUrlString,
        link: true,
        onClick: onShare,
        target: "_blank"
      }, rest, {
        children: literal
      }), index);
    })
  });
}
ShareSocialMediaButtonsGroup.displayName = 'ShareSocialMediaButtonsGroup';
export { DEFAULT_SOCIAL_MEDIA_DICTIONARY as socialMediaDictionary };

==> sui-share-social-media-buttons-group-1.2.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import AtomButton from '@s-ui/react-atom-button';
import DEFAULT_SOCIAL_MEDIA_DICTIONARY, { DEFAULT_SOCIAL_MEDIA_BUTTONS } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
var BASE_CLASS = 'sui-ShareSocialMediaButtonsGroup';
export default function ShareSocialMediaButtonsGroup(_ref) {
  var _ref$buttonsToShow = _ref.buttonsToShow,
      buttonsToShow = _ref$buttonsToShow === void 0 ? DEFAULT_SOCIAL_MEDIA_BUTTONS : _ref$buttonsToShow,
      onShare = _ref.onShare,
      _ref$paramsUrlString = _ref.paramsUrlString,
      paramsUrlString = _ref$paramsUrlString === void 0 ? '' : _ref$paramsUrlString,
      _ref$socialMediaDicti = _ref.socialMediaDictionary,
      socialMediaDictionaryFromProps = _ref$socialMediaDicti === void 0 ? DEFAULT_SOCIAL_MEDIA_DICTIONARY : _ref$socialMediaDicti;
  var socialMediaDictionary = buttonsToShow.map(function (key) {
    return Object.keys(socialMediaDictionaryFromProps).includes(key) && socialMediaDictionaryFromProps[key];
  });
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: socialMediaDictionary.map(function (_ref2, index) {
      var literal = _ref2.literal,
          url = _ref2.url,
          rest = _objectWithoutPropertiesLoose(_ref2, ["literal", "url"]);

      return /*#__PURE__*/_jsx(AtomButton, _extends({
        className: BASE_CLASS + "-button",
        href: "" + url + paramsUrlString,
        link: true,
        onClick: onShare,
        target: "_blank"
      }, rest, {
        children: literal
      }), index);
    })
  });
}
ShareSocialMediaButtonsGroup.displayName = 'ShareSocialMediaButtonsGroup';
export { DEFAULT_SOCIAL_MEDIA_DICTIONARY as socialMediaDictionary };
